# -*- coding: utf-8 -*-
#
# Created on Oct 15, 2013
# @authors: Jiri Spilka
# http://people.ciirc.cvut.cz/~spilkjir
# @2015, CIIRC, Czech Technical University in Prague
#
# Licensed under the terms of the GNU GENERAL PUBLIC LICENSE
# (see CTGViewerLite.py for details)

import sys

from PyQt4.QtGui import QWidget, QVBoxLayout, QApplication, QMainWindow
from PyQt4 import Qt
from PyQwtWidgetGui import FhrPlot
from PyQwtWidgetGui import TocoPlot
from PyQwtNavigationPlot import PyQwtNavigationPlot
from Annotator import Annotator, EnumAnnType


class PlotWidget(QWidget):
    """

        * parent
    """

    def __init__(self, parent=None):
        QWidget.__init__(self, parent)

        # self.setMinimumSize(600, 600)
        self.setMinimumSize(700, 550)
        # self.setMaximumSize(1200,800)
        
        # self._styleManager = styleManager()
        # self._styleManager.setStyleManager(self._styleManager)

        self.annotator = Annotator()

        vbox = QVBoxLayout()

        controled_plots = list()
        self.fhrPlot = FhrPlot(self)
        self.tocoPlot = TocoPlot(self)
        # self.tocoPlot.setSizePolicy(QSizePolicy.Minimum,QSizePolicy.Minimum)

        controled_plots.append(self.fhrPlot)
        controled_plots.append(self.tocoPlot)
        self.navPlot = PyQwtNavigationPlot(self, controled_plots)

        # self.plotTools = PyQwtPlotTools(self, self.fhrPlot, self._styleManager)
        # self.plot.setMargin(5)

        vbox.addWidget(self.fhrPlot)
        vbox.addWidget(self.tocoPlot)
        # vbox.addLayout(self.plotTools.ToolbarHBoxLayout)
        vbox.addWidget(self.navPlot)
        self.setLayout(vbox)
        # self.setCentralWidget(self.fhrPlot)
        # self.setMinimumSize(90, 90)
        # self.setMinimumSize(1000, 100)

        self.fhrPlot.signal_ann_changed.connect(self.update_nav_plot)
        self.fhrPlot.canvas_picker.signal_ann_moved_outside_view.connect(self.ann_moved_outside_view)

    def setSamplingFreqAllPlots(self, fs):
        self.fhrPlot.set_sampling_freq(fs)
        self.tocoPlot.set_sampling_freq(fs)
        self.navPlot.set_sampling_freq(fs)

    def getSamplingFreq(self):
        return self._samplingFreq

    def plot(self, time_samples, fhr, toco, timestring=None):

        self.clearAllPlots()
        self.fhrPlot.plot(time_samples, fhr, timestring)
        self.tocoPlot.plot(time_samples, toco, timestring)
        self.navPlot.plot(time_samples, fhr, timestring)

    def plot_stage1_line(self, stage1pos_samp):
        self.fhrPlot.plot_first_stage_line(stage1pos_samp)
        self.tocoPlot.plot_first_stage_line(stage1pos_samp)
        self.navPlot.plot_first_stage_line(stage1pos_samp)

    def plot_stage2_line(self, stage2pos_samp):
        self.fhrPlot.plot_second_stage_line(stage2pos_samp)
        self.tocoPlot.plot_second_stage_line(stage2pos_samp)
        self.navPlot.plot_second_stage_line(stage2pos_samp)

    # def plot_baseline_constant(self, val):
    #     self.fhrPlot.plot_baseline_constant(val)

    def clearAllPlots(self):
        self.fhrPlot.clearPlot()
        self.tocoPlot.clearPlot()
        self.navPlot.clearPlot()
        self.navPlot.clear_selected_point()

    def updatePlots(self):
        self.fhrPlot.updateAxis()
        self.tocoPlot.updateAxis()
        self.navPlot.setXAxis()
        self.navPlot.correct_point_boundaries()

    def set_paper_eu(self):
        self.fhrPlot.set_paper_eu()
        self.tocoPlot.set_paper_eu()
        self.navPlot.set_paper_eu()
        self.updatePlots()

    def set_paper_us(self):
        self.fhrPlot.set_paper_us()
        self.tocoPlot.set_paper_us()
        self.navPlot.set_paper_us()
        self.updatePlots()

    def set_ann_action(self, action):
        self.fhrPlot.set_ann_action(action)

    def ann_file_load_and_plot(self, sfile):
        self.annotator.ann_file_load(sfile)
        self.ann_set_and_plot()

    def ann_set_and_plot(self):
        self.fhrPlot.ann_set_and_plot(self.annotator.get_annotations())
        self.navPlot.ann_set(self.annotator.get_annotations_copy())
        self.navPlot.plot_ann_navplot_marker()

    def delete_annotations(self):
        self.fhrPlot.ann_delete_all()
        self.navPlot.ann_delete_all()

    def ann_save(self):
        self.annotator.set_annotations_and_save(self.fhrPlot.d_ann_all_curves)

    def ann_moved_outside_view(self, step):
        if step > 0:
            self.navPlot.change_selected_pointright(step)
        else:
            self.navPlot.change_selected_pointleft(abs(step))

    def update_nav_plot(self):
        self.navPlot.ann_set(self.annotator.get_annotations_copy())
        self.navPlot.plot_ann_navplot_marker()

    def resizeEvent(self, ev):
        self.updatePlots()

    def keyPressEvent(self, event):

        if event.key() == Qt.Qt.Key_Left:
            self.navPlot.change_selected_pointleft()

        if event.key() == Qt.Qt.Key_Right:
            self.navPlot.change_selected_pointright()

        return QWidget.keyPressEvent(self, event)

    def wheelEvent(self, event):

        if event.delta() > 0:
            self.navPlot.change_selected_pointleft()
        elif event.delta() < 0:
            self.navPlot.change_selected_pointright()

        return QWidget.wheelEvent(self, event)

    def mousePressEvent(self, event):
        # print 'mpress'
        return QWidget.mousePressEvent(self, event)


def main():
    app = QApplication(sys.argv)
    window = PlotWidget()
    window.show()
    window.updatePlots()
    sys.exit(app.exec_())

if __name__ == '__main__':
        main()

